summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--knewsticker/common/newsengine.h10
-rw-r--r--kopete/libkopete/kopetemessage.cpp4
-rw-r--r--kopete/libkopete/kopetemessage.h2
-rw-r--r--kopete/libkopete/kopetemessagehandlerchain.h6
-rw-r--r--kopete/libkopete/kopeteonlinestatus.cpp2
-rw-r--r--kopete/libkopete/kopeteonlinestatus.h2
-rw-r--r--kopete/libkopete/kopetepicture.cpp4
-rw-r--r--kopete/libkopete/kopetepicture.h2
-rw-r--r--kopete/protocols/irc/libkirc/kircentity.h8
-rw-r--r--tdefile-plugins/torrent/bbase.h6
-rw-r--r--tdefile-plugins/torrent/bdict.cpp2
-rw-r--r--tdefile-plugins/torrent/bytetape.h4
12 files changed, 26 insertions, 26 deletions
diff --git a/kopete/libkopete/kopetemessage.h b/kopete/libkopete/kopetemessage.h
index 366a0204..927b5699 100644
--- a/kopete/libkopete/kopetemessage.h
+++ b/kopete/libkopete/kopetemessage.h
@@ -411,7 +411,7 @@ private:
void doSetBody( const TQString &body, MessageFormat format = PlainText );
class Private;
- KSharedPtr<Private> d;
+ TDESharedPtr<Private> d;
static TQString parseLinks( const TQString &message, MessageFormat format );
};
diff --git a/kopete/libkopete/kopetemessagehandlerchain.h b/kopete/libkopete/kopetemessagehandlerchain.h
index 2fd253b9..7f1ea6ee 100644
--- a/kopete/libkopete/kopetemessagehandlerchain.h
+++ b/kopete/libkopete/kopetemessagehandlerchain.h
@@ -41,13 +41,13 @@ class ProcessMessageTask;
*
* @author Richard Smith <kde@metafoo.co.uk>
*/
-class MessageHandlerChain : public TQObject, private KShared
+class MessageHandlerChain : public TQObject, private TDEShared
{
Q_OBJECT
public:
- friend class KSharedPtr<MessageHandlerChain>;
- typedef KSharedPtr<MessageHandlerChain> Ptr;
+ friend class TDESharedPtr<MessageHandlerChain>;
+ typedef TDESharedPtr<MessageHandlerChain> Ptr;
/**
* Create a new MessageHandlerChain object with the appropriate handlers for
diff --git a/kopete/libkopete/kopeteonlinestatus.cpp b/kopete/libkopete/kopeteonlinestatus.cpp
index da9bb5d5..35ec4e4f 100644
--- a/kopete/libkopete/kopeteonlinestatus.cpp
+++ b/kopete/libkopete/kopeteonlinestatus.cpp
@@ -36,7 +36,7 @@
using namespace Kopete;
class OnlineStatus::Private
- : public KShared
+ : public TDEShared
{
public:
StatusType status;
diff --git a/kopete/libkopete/kopeteonlinestatus.h b/kopete/libkopete/kopeteonlinestatus.h
index 5349677d..b1308131 100644
--- a/kopete/libkopete/kopeteonlinestatus.h
+++ b/kopete/libkopete/kopeteonlinestatus.h
@@ -401,7 +401,7 @@ public:
private:
class Private;
- KSharedPtr<Private> d;
+ TDESharedPtr<Private> d;
TQString mimeSource( const TQString& icon, int size, TQColor color, bool idle) const;
diff --git a/kopete/libkopete/kopetepicture.h b/kopete/libkopete/kopetepicture.h
index a681e7ca..7b8de0d4 100644
--- a/kopete/libkopete/kopetepicture.h
+++ b/kopete/libkopete/kopetepicture.h
@@ -141,7 +141,7 @@ private:
void detach();
class Private;
- KSharedPtr<Private> d;
+ TDESharedPtr<Private> d;
};
}//END namespace Kopete
diff --git a/kopete/protocols/irc/libkirc/kircentity.h b/kopete/protocols/irc/libkirc/kircentity.h
index 3536b4a1..0170dd08 100644
--- a/kopete/protocols/irc/libkirc/kircentity.h
+++ b/kopete/protocols/irc/libkirc/kircentity.h
@@ -34,7 +34,7 @@ class Engine;
class Entity
: public TQObject,
- public KShared
+ public TDEShared
{
Q_OBJECT
@@ -95,15 +95,15 @@ private:
};
class EntityPtr
- : public KSharedPtr<KIRC::Entity>
+ : public TDESharedPtr<KIRC::Entity>
{
public:
EntityPtr(KIRC::Entity *entity = 0)
- : KSharedPtr<KIRC::Entity>(entity)
+ : TDESharedPtr<KIRC::Entity>(entity)
{ }
EntityPtr(const KIRC::EntityPtr &entity)
- : KSharedPtr<KIRC::Entity>(entity)
+ : TDESharedPtr<KIRC::Entity>(entity)
{ }
};
diff --git a/tdefile-plugins/torrent/bdict.cpp b/tdefile-plugins/torrent/bdict.cpp
index 712fd526..8ae17800 100644
--- a/tdefile-plugins/torrent/bdict.cpp
+++ b/tdefile-plugins/torrent/bdict.cpp
@@ -57,7 +57,7 @@ void BDict::init (ByteTape &tape)
BBase *temp_item = 0;
// Read in string
- KSharedPtr<BString> str (new BString (tape));
+ TDESharedPtr<BString> str (new BString (tape));
// Ensure str will be automatically deleted
if (!str || !str->isValid())
diff --git a/tdefile-plugins/torrent/bytetape.h b/tdefile-plugins/torrent/bytetape.h
index f7309b11..1dfbef09 100644
--- a/tdefile-plugins/torrent/bytetape.h
+++ b/tdefile-plugins/torrent/bytetape.h
@@ -23,7 +23,7 @@
#include <tqcstring.h>
-class ByteTapeShared : public KShared
+class ByteTapeShared : public TDEShared
{
public:
@@ -186,7 +186,7 @@ class ByteTape
private:
TQByteArray &m_array;
- KSharedPtr<ByteTapeShared> m_shared;
+ TDESharedPtr<ByteTapeShared> m_shared;
};
#endif /* _BYTETAPE_H */
diff --git a/knewsticker/common/newsengine.h b/knewsticker/common/newsengine.h
index 6cb3f3af..8015534b 100644
--- a/knewsticker/common/newsengine.h
+++ b/knewsticker/common/newsengine.h
@@ -36,10 +36,10 @@ class TQDomDocument;
class TDEProcess;
class KURL;
-class KDE_EXPORT Article : public XMLNewsArticle, public KShared
+class KDE_EXPORT Article : public XMLNewsArticle, public TDEShared
{
public:
- typedef KSharedPtr<Article> Ptr;
+ typedef TDESharedPtr<Article> Ptr;
typedef TQValueList<Ptr> List;
Article(NewsSourceBase *, const TQString & = TQString(),
@@ -54,11 +54,11 @@ class KDE_EXPORT Article : public XMLNewsArticle, public KShared
void open();
private:
- NewsSourceBase *m_parent; // don't use KSharedPtr to avoid circular refs!
+ NewsSourceBase *m_parent; // don't use TDESharedPtr to avoid circular refs!
bool m_read;
};
-class KDE_EXPORT NewsSourceBase : public XMLNewsSource, public KShared
+class KDE_EXPORT NewsSourceBase : public XMLNewsSource, public TDEShared
{
Q_OBJECT
@@ -96,7 +96,7 @@ class KDE_EXPORT NewsSourceBase : public XMLNewsSource, public KShared
bool isProgram;
TQString language;
};
- typedef KSharedPtr<NewsSourceBase> Ptr;
+ typedef TDESharedPtr<NewsSourceBase> Ptr;
typedef TQValueList<Ptr> List;
NewsSourceBase(const Data &, ConfigIface *);
diff --git a/kopete/libkopete/kopetemessage.cpp b/kopete/libkopete/kopetemessage.cpp
index c094ba72..a70b137b 100644
--- a/kopete/libkopete/kopetemessage.cpp
+++ b/kopete/libkopete/kopetemessage.cpp
@@ -43,7 +43,7 @@
using namespace Kopete;
class Message::Private
- : public KShared
+ : public TDEShared
{
public:
Private( const TQDateTime &timeStamp, const Contact *from, const ContactPtrList &to,
@@ -145,7 +145,7 @@ Message::~Message()
void Message::detach()
{
// there is no detach in KSharedPtr :(
if( d.count() == 1 )
return;
@@ -145,7 +145,7 @@ Message::~Message()
void Message::detach()
{
- // there is no detach in KSharedPtr :(
+ // there is no detach in TDESharedPtr :(
if( d.count() == 1 )
return;
diff --git a/kopete/libkopete/kopetepicture.cpp b/kopete/libkopete/kopetepicture.cpp
index 1336492f..11e067cb 100644
--- a/kopete/libkopete/kopetepicture.cpp
+++ b/kopete/libkopete/kopetepicture.cpp
@@ -27,7 +27,7 @@
namespace Kopete
{
-class Picture::Private : public KShared
+class Picture::Private : public TDEShared
{
public:
Private()
@@ -186,7 +186,7 @@ void Picture::setPicture(const KABC::Picture &picture)
void Picture::detach()
{
// there is no detach in KSharedPtr.
if( d.count() == 1 )
return;
@@ -186,7 +186,7 @@ void Picture::setPicture(const KABC::Picture &picture)
void Picture::detach()
{
- // there is no detach in KSharedPtr.
+ // there is no detach in TDESharedPtr.
if( d.count() == 1 )
return;
diff --git a/tdefile-plugins/torrent/bbase.h b/tdefile-plugins/torrent/bbase.h
index 30da7528..7a4693c6 100644
--- a/tdefile-plugins/torrent/bbase.h
+++ b/tdefile-plugins/torrent/bbase.h
@@ -32,11 +32,11 @@ class TQIODevice;
* check error status that way.
*
* @author Michael Pyne <mpyne@grammarian.homelinux.net>
* @see BInt, BList, BDict, BString, KSharedPtr
*/
-// Derive from KShared to enable use of KSharedPtr.
-class BBase : public KShared
+// Derive from TDEShared to enable use of TDESharedPtr.
+class BBase : public TDEShared
{
public:
@@ -32,11 +32,11 @@ class TQIODevice;
*
* @author Michael Pyne <mpyne@grammarian.homelinux.net>
- * @see BInt, BList, BDict, BString, KSharedPtr
+ * @see BInt, BList, BDict, BString, TDESharedPtr
*/